@@ -1,4 +1,4 @@
-// Copyright(C) 1999-2024 National Technology & Engineering Solutions
+// Copyright(C) 1999-2025 National Technology & Engineering Solutions
 // of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
 // NTESS, the U.S. Government retains certain rights in this software.
 //
@@ -33,8 +33,8 @@
 #endif
 
 namespace {
-  const std::string version_short{"6.32"};
-  const std::string version_date{"(2024/05/20)"};
+  const std::string version_short{"6.37"};
+  const std::string version_date{"(2025/03/06)"};
   const std::string version_string = version_short + " " + version_date;
 
   void output_copyright();
@@ -52,6 +52,16 @@ namespace {
     }
     return value;
   }
+
+  void format_option(std::string_view option, std::string_view short_opt,
+                     std::string_view description)
+  {
+    fmt::print(stderr, fmt::emphasis::bold, "{}", option);
+    if (!short_opt.empty()) {
+      fmt::print(stderr, " or {}", fmt::styled(short_opt, fmt::emphasis::bold));
+    }
+    fmt::print(stderr, ":  {}\n", description);
+  }
 } // namespace
 
 namespace SEAMS {
@@ -137,7 +147,7 @@ namespace SEAMS {
 
   std::string Aprepro::long_version() const
   {
-    auto comment = getsym("_C_")->value.svar;
+    const auto &comment = getsym("_C_")->value.svar;
     return comment + " Algebraic Preprocessor (Aprepro) version " + version();
   }
 
@@ -447,7 +457,7 @@ namespace SEAMS {
                       const std::string &short_opt, size_t min_length)
     {
       // See if `option` starts with 1 or 2 leading `-`.
-      int number_dash = option[0] == '-' ? (option[1] == '-' ? 2 : 1) : 0;
+      size_t number_dash = option[0] == '-' ? (option[1] == '-' ? 2 : 1) : 0;
 
       // See if `option` contains a `=`, save position...
       auto equals = option.find('=');
@@ -580,50 +590,69 @@ namespace SEAMS {
         ptr->value.svar = "";
       }
     }
+    else if (match_option(option, "legacy_output_format", "L", 6)) {
+      symrec *ptr = getsym("_FORMAT");
+      if (ptr != nullptr) {
+        ptr->value.svar = "%.10g";
+      }
+    }
 
     else if (match_option(option, "help", "h", 3)) {
-      std::cerr
-          << "\nAprepro version " << version() << "\n"
-          << "\nUsage: aprepro [options] [-I path] [-c char] [var=val] [filein] [fileout]\n"
-          << "          --debug or -d: Dump all variables, debug loops/if/endif and keep temporary "
-             "files\n"
-          << "       --dumpvars or -D: Dump all variables at end of run        \n"
-          << "  --dumpvars_json or -J: Dump all variables at end of run in json format\n"
-          << "        --version or -v: Print version number to stderr          \n"
-          << "      --immutable or -X: All variables are immutable--cannot be modified\n"
-          << "   --errors_fatal or -f: Exit program with nonzero status if errors are "
-             "encountered\n"
-          << " --errors_and_warnings_fatal or -F: Exit program with nonzero status if "
-             "warnings are encountered\n"
-          << "--require_defined or -R: Treat undefined variable warnings as fatal\n"
-          << "--one_based_index or -1: Array indexing is one-based (default = zero-based)\n"
-          << "    --interactive or -i: Interactive use, no buffering           \n"
-          << "    --include=P or -I=P: Include file or include path            \n"
-          << "                       : If P is path, then optionally prepended to all include "
-             "filenames\n"
-          << "                       : If P is file, then processed before processing input file\n"
-          << "                       : variables defined in P will be immutable.\n"
-          << "        --exit_on or -e: End when 'Exit|EXIT|exit' entered       \n"
-          << "           --help or -h: Print this list                         \n"
-          << "        --message or -M: Print INFO messages                     \n"
-          << "            --info=file: Output INFO messages (e.g. DUMP() output) to file.\n"
-          << "      --nowarning or -W: Do not print WARN messages              \n"
-          << "  --comment=char or -c=char: Change comment character to 'char'  \n"
-          << "    --full_precision -p: Floating point output uses as many digits as needed.\n"
-          << "      --copyright or -C: Print copyright message                 \n"
-          << "   --keep_history or -k: Keep a history of aprepro substitutions.\n"
-          << "                         (not for general interactive use)       \n"
-          << "          --quiet or -q: Do not print the header output line     \n"
-          << "                var=val: Assign value 'val' to variable 'var'    \n"
-          << "                         Use var=\\\"sval\\\" for a string variable. 'var' will be "
-             "immutable.\n\n"
-          << "\tUnits Systems: si, cgs, cgs-ev, shock, swap, ft-lbf-s, ft-lbm-s, in-lbf-s\n"
-          << "\tEnter {DUMP()} for list of user-defined variables\n"
-          << "\tEnter {DUMP_FUNC()} for list of functions recognized by aprepro\n"
-          << "\tEnter {DUMP_PREVAR()} for list of predefined variables in aprepro\n\n"
-          << "\tDocumentation: "
-             "https://sandialabs.github.io/seacas-docs/sphinx/html/index.html#aprepro\n\n"
-          << "\t->->-> Send email to gdsjaar@sandia.gov for aprepro support.\n\n";
+      fmt::print(stderr,
+                 "\nAprepro version {}\n\n"
+                 "\tUsage: aprepro [options] [-I path] [-c char] [var=val] [filein] [fileout]\n\n",
+                 version());
+
+      format_option("            --debug", "-d",
+                    "Dump all variables, debug loops/if/endif and keep temporary files");
+      format_option("         --dumpvars", "-D", "Dump all variables at end of run        ");
+      format_option("    --dumpvars_json", "-J", "Dump all variables at end of run in json format");
+      format_option("          --version", "-v", "Print version number to stderr          ");
+      format_option("        --immutable", "-X", "All variables are immutable--cannot be modified");
+      format_option("     --errors_fatal", "-f",
+                    "Exit program with nonzero status if errors are encountered");
+      format_option("--errors_and_warnings_fatal", "-F",
+                    "Exit program with nonzero status if warnings are encountered");
+      format_option("  --require_defined", "-R", "Treat undefined variable warnings as fatal");
+      format_option("  --one_based_index", "-1",
+                    "Array indexing is one-based (default = zero-based)");
+      format_option("      --interactive", "-i", "Interactive use, no buffering           ");
+      format_option("      --include=P", "-I=P", "Include file or include path            ");
+      format_option("                         ", "",
+                    "If P is path, then optionally prepended to all include filenames");
+      format_option("                         ", "",
+                    "If P is file, then processed before processing input file");
+      format_option("                         ", "", "variables defined in P will be immutable.");
+      format_option("          --exit_on", "-e", "End when 'Exit|EXIT|exit' entered       ");
+      format_option("             --help", "-h", "Print this list                         ");
+      format_option("          --message", "-M", "Print INFO messages                     ");
+      format_option("              --info=file", "",
+                    "Output INFO messages (e.g. DUMP() output) to file.");
+      format_option("        --nowarning", "-W", "Do not print WARN messages              ");
+      format_option("--comment=char", "-c=char", "Change comment character to 'char'  ");
+      format_option("   --full_precision", "-p",
+                    "Floating point output uses as many digits as needed. [default]");
+      format_option("--legacy_output_format", "-L",
+                    "Floating point output uses the legacy `%.10g` format.");
+      format_option("        --copyright", "-C", "Print copyright message                 ");
+      format_option("     --keep_history", "-k", "Keep a history of aprepro substitutions.");
+      format_option("                         ", "", "(not for general interactive use)       ");
+      format_option("            --quiet", "-q", "Do not print the header output line     ");
+      format_option("                  var=val", "", "Assign value 'val' to variable 'var'");
+      format_option("                         ", "",
+                    "Use var=\\\"sval\\\" for a string variable. 'var' will be immutable.\n");
+      fmt::print(stderr,
+                 "\tUnits Systems: si, cgs, cgs-ev, shock, swap, ft-lbf-s, ft-lbm-s, in-lbf-s\n");
+      fmt::print(stderr, "\tEnter {} for list of user-defined variables\n",
+                 fmt::styled("{{DUMP()}}", fmt::emphasis::bold));
+      fmt::print(stderr, "\tEnter {} for list of functions recognized by aprepro\n",
+                 fmt::styled("{{DUMP_FUNC()}}", fmt::emphasis::bold));
+      fmt::print(stderr, "\tEnter {} for list of predefined variables in aprepro\n\n",
+                 fmt::styled("{{DUMP_PREVAR()}}", fmt::emphasis::bold));
+      fmt::print(stderr,
+                 "\tDocumentation: "
+                 "https://sandialabs.github.io/seacas-docs/sphinx/html/index.html#aprepro\n\n"
+                 "\t->->-> Send email to gdsjaar@sandia.gov for aprepro support.\n\n");
       exit(EXIT_SUCCESS);
     }
     else {
@@ -632,7 +661,7 @@ namespace SEAMS {
     return ret_value;
   }
 
-  array *Aprepro::make_array(int r, int c)
+  array *Aprepro::make_array(size_t r, size_t c)
   {
     auto ptr = new array(r, c);
     array_allocations.push_back(ptr);
